@@ -46,7 +46,7 @@ from .basic_components import (
     Telephone,
     UUID,
 )
-from .common import BaseElement, CacMixin
+from .common import BaseElement, CacMixin, WithAsMixin
 
 # =============================================================================
 # Group 1: Foundation Components
@@ -87,9 +87,9 @@ class Contact(CacMixin, BaseElement):
     name: Name | None = field(default=None, kw_only=True)
 
     class_name_to_attr: ClassVar[dict[str, str]] = {
-        'ElectronicMail': 'electronic_mail',
-        'Telephone': 'telephone',
         'Name': 'name',
+        'Telephone': 'telephone',
+        'ElectronicMail': 'electronic_mail',
     }
 
 
@@ -112,7 +112,14 @@ class TaxScheme(CacMixin, BaseElement):
 
         # Create default VAT ID if none provided
         if self.id is None:
-            self.id = ID(value='VAT', schemeID='UN/ECE 5153', schemeAgencyID='6')
+            from ..context import is_peppol_mode
+
+            if is_peppol_mode():
+                # PEPPOL: TaxScheme ID without schemeID/schemeAgencyID (BR-CL-10)
+                self.id = ID(value='VAT')
+            else:
+                # Standard: TaxScheme ID with UN/ECE codelist
+                self.id = ID(value='VAT', schemeID='UN/ECE 5153', schemeAgencyID='6')
 
 
 # =============================================================================
@@ -225,11 +232,31 @@ class FinancialInstitutionBranch(CacMixin, BaseElement):
     id: Identifier | None = field(default=None, kw_only=True)
     financial_institution: FinancialInstitution | None = field(default=None, kw_only=True)
 
-    class_name_to_attr: ClassVar[dict[str, str]] = {
+    _base_class_name_to_attr: ClassVar[dict[str, str]] = {
         'ID': 'id',
         'FinancialInstitution': 'financial_institution',
     }
 
+    @property
+    def class_name_to_attr(self) -> dict[str, str]:
+        """
+        Get element mapping, filtered for PEPPOL mode.
+
+        PEPPOL/CEN UBL-CR-664: Should not include FinancialInstitution element.
+
+        Returns:
+            Filtered mapping dictionary
+        """
+        from ..context import is_peppol_mode
+
+        mapping = self._base_class_name_to_attr.copy()
+
+        if is_peppol_mode():
+            # UBL-CR-664: Remove FinancialInstitution
+            mapping.pop('FinancialInstitution', None)
+
+        return mapping
+
 
 @dataclass
 class PayeeFinancialAccount(CacMixin, BaseElement):
@@ -246,12 +273,32 @@ class PayeeFinancialAccount(CacMixin, BaseElement):
     name: Name | None = field(default=None, kw_only=True)
     financial_institution_branch: FinancialInstitutionBranch | None = field(default=None, kw_only=True)
 
-    class_name_to_attr: ClassVar[dict[str, str]] = {
+    _base_class_name_to_attr: ClassVar[dict[str, str]] = {
         'ID': 'id',
         'Name': 'name',
         'FinancialInstitutionBranch': 'financial_institution_branch',
     }
 
+    @property
+    def class_name_to_attr(self) -> dict[str, str]:
+        """
+        Get element mapping, filtered for PEPPOL mode.
+
+        PEPPOL/CEN UBL-CR-664: Should not include FinancialInstitutionBranch.
+
+        Returns:
+            Filtered mapping dictionary
+        """
+        from ..context import is_peppol_mode
+
+        mapping = self._base_class_name_to_attr.copy()
+
+        if is_peppol_mode():
+            # UBL-CR-664: Remove FinancialInstitutionBranch
+            mapping.pop('FinancialInstitutionBranch', None)
+
+        return mapping
+
 
 # =============================================================================
 # Group 4: Tax Components
@@ -259,7 +306,7 @@ class PayeeFinancialAccount(CacMixin, BaseElement):
 
 
 @dataclass
-class TaxCategory(CacMixin, BaseElement):
+class TaxCategory(CacMixin, WithAsMixin, BaseElement):
     """
     UBL cac:TaxCategory - Tax category with rate.
 
@@ -302,8 +349,15 @@ class TaxCategory(CacMixin, BaseElement):
             self.tax_scheme = TaxScheme()
 
 
-# Alias for item-level tax categories (same as TaxCategory)
-ClassifiedTaxCategory = TaxCategory
+@dataclass
+class ClassifiedTaxCategory(TaxCategory):
+    """
+    Alias for item-level tax categories (renders as ClassifiedTaxCategory).
+
+    Functionally identical to TaxCategory but with different XML element name.
+    Used in Item to specify the tax category for a product/service.
+    """
+    _element_name = 'ClassifiedTaxCategory'
 
 
 @dataclass
@@ -327,13 +381,33 @@ class TaxSubtotal(CacMixin, BaseElement):
     tax_category: TaxCategory
     percent: Percent | None = field(default=None, kw_only=True)
 
-    class_name_to_attr: ClassVar[dict[str, str]] = {
+    _base_class_name_to_attr: ClassVar[dict[str, str]] = {
         'TaxableAmount': 'taxable_amount',
         'TaxAmount': 'tax_amount',
         'Percent': 'percent',
         'TaxCategory': 'tax_category',
     }
 
+    @property
+    def class_name_to_attr(self) -> dict[str, str]:
+        """
+        Get element mapping, filtered for PEPPOL mode.
+
+        PEPPOL/CEN UBL-CR-499: TaxSubtotal should not include Percent element.
+
+        Returns:
+            Filtered mapping dictionary
+        """
+        from ..context import is_peppol_mode
+
+        mapping = self._base_class_name_to_attr.copy()
+
+        if is_peppol_mode():
+            # UBL-CR-499: Remove Percent
+            mapping.pop('Percent', None)
+
+        return mapping
+
     def __post_init__(self) -> None:
         """Derive percent from tax_category if not provided."""
         self._super_post_init(super())
@@ -514,7 +588,7 @@ class Item(CacMixin, BaseElement):
     name: Name | None = field(default=None, kw_only=True)
     description: Description | None = field(default=None, kw_only=True)
     sellers_item_identification: SellersItemIdentification | None = field(default=None, kw_only=True)
-    classified_tax_category: TaxCategory | None = field(default=None, kw_only=True)
+    classified_tax_category: ClassifiedTaxCategory | None = field(default=None, kw_only=True)
 
     class_name_to_attr: ClassVar[dict[str, str]] = {
         'Name': 'name',
@@ -564,17 +638,37 @@ class InvoiceLine(CacMixin, BaseElement):
     notes: list[Note] = field(default_factory=list, kw_only=True)
     tax_total: TaxTotal | None = field(default=None, kw_only=True)
 
-    class_name_to_attr: ClassVar[dict[str, str]] = {
+    _base_class_name_to_attr: ClassVar[dict[str, str]] = {
         'ID': 'id',
         'UUID': 'uuid',
         'Note': 'notes',
         'InvoicedQuantity': 'invoiced_quantity',
         'LineExtensionAmount': 'line_extension_amount',
+        'TaxTotal': 'tax_total',  # UBL 2.1: TaxTotal must come before Item and Price
         'Item': 'item',
         'Price': 'price',
-        'TaxTotal': 'tax_total',
     }
 
+    @property
+    def class_name_to_attr(self) -> dict[str, str]:
+        """
+        Get element mapping, filtered for PEPPOL mode.
+
+        PEPPOL/CEN UBL-CR-561: InvoiceLine should not include TaxTotal element.
+
+        Returns:
+            Filtered mapping dictionary
+        """
+        from ..context import is_peppol_mode
+
+        mapping = self._base_class_name_to_attr.copy()
+
+        if is_peppol_mode():
+            # UBL-CR-561: Remove TaxTotal
+            mapping.pop('TaxTotal', None)
+
+        return mapping
+
     def __post_init__(self) -> None:
         """Validate line extension amount = quantity × price (if both present)."""
         # First: trigger type casting through mixin chain
@@ -766,12 +860,18 @@ class PartyIdentification(CacMixin, BaseElement):
         Compare identifiers accounting for dual representation.
 
         9925:be0867709540 == BE:VAT:BE0867709540 (same scheme, case-insensitive value)
+
+        Uses child Identifier's schemeID as canonical value after __post_init__.
         """
         if not isinstance(other, PartyIdentification):
             return False
 
+        # Use child Identifier's schemeID as canonical value (handles extraction failures)
+        self_scheme = self.id.schemeID if self.id else self.schemeID
+        other_scheme = other.id.schemeID if other.id else other.schemeID
+
         # Same scheme (case-insensitive value)
-        if self.schemeID == other.schemeID:
+        if self_scheme == other_scheme:
             return self.value.lower() == other.value.lower()
 
         # Different schemes - check if equivalent via iso6523
@@ -782,8 +882,14 @@ class PartyIdentification(CacMixin, BaseElement):
         return False
 
     def __hash__(self) -> int:
-        """Hash for deduplication in sets and dicts."""
-        return hash((self.value.lower(), self.schemeID))
+        """
+        Hash for deduplication in sets and dicts.
+
+        Uses child Identifier's schemeID as canonical value after __post_init__.
+        """
+        # Use child Identifier's schemeID as canonical value (handles extraction failures)
+        scheme_for_hash = self.id.schemeID if self.id else self.schemeID
+        return hash((self.value.lower(), scheme_for_hash))
 
     def deserialize(self) -> dict:
         """
@@ -940,8 +1046,8 @@ class Party(CacMixin, BaseElement):
 
     class_name_to_attr: ClassVar[dict[str, str]] = {
         'EndpointID': 'endpoint_id',
-        'PartyName': 'party_name',
         'PartyIdentification': 'party_identification_list',
+        'PartyName': 'party_name',
         'PostalAddress': 'postal_address',
         'PartyTaxScheme': 'party_tax_scheme',
         'PartyLegalEntity': 'party_legal_entity',
@@ -1053,27 +1159,75 @@ class Party(CacMixin, BaseElement):
     @property
     def party_identification_list(self) -> list[PartyIdentification]:
         """
-        All identifiers as PartyIdentification list.
+        First identifier as PartyIdentification list.
 
-        Used for cac:PartyIdentification elements (multiple allowed).
+        PEPPOL BIS 3.0 (UBL-SR-16) requires only ONE buyer/seller party identification.
+        PEPPOL/CEN BR-CL-10 requires schemeID in range 0002-0240 for PartyIdentification.
 
         Returns:
-            List of PartyIdentification objects (empty if no identifiers)
+            List with single PartyIdentification object:
+            - In PEPPOL mode: First identifier with schemeID in range 0002-0240
+            - Standard mode: First identifier from all_identifiers
+            Empty list if no suitable identifiers found
         """
-        return self.all_identifiers
+        from ..context import is_peppol_mode
+
+        identifiers = self.all_identifiers
+        if not identifiers:
+            return []
+
+        # In PEPPOL mode, filter for CEN-approved codes (0002-0240)
+        if is_peppol_mode():
+            for identifier in identifiers:
+                scheme_id = identifier.schemeID
+                # Check if schemeID is a 4-digit number in range 0002-0240
+                if scheme_id and scheme_id.isdigit() and len(scheme_id) == 4:
+                    code = int(scheme_id)
+                    if 2 <= code <= 240:
+                        return [identifier]
+
+            # No approved identifier found - return empty list
+            # This will prevent BR-CL-10 errors rather than using invalid code
+            return []
+
+        # Standard mode: return first identifier
+        return [identifiers[0]]
 
     @property
     def party_tax_scheme(self) -> PartyTaxScheme | None:
         """
         Tax registration scheme (if VAT available).
 
+        PEPPOL BIS 3.0 / CEN EN16931:
+        - UBL-CR-652: CompanyID should not include schemeID attribute
+        - In PEPPOL mode, omit schemeID and use plain VAT value
+
         Returns:
-            PartyTaxScheme or None if no VAT or country_code
+            PartyTaxScheme with or without schemeID based on mode
         """
+        from ..context import is_peppol_mode
+
         if self.vat and self.country_code:
-            return PartyTaxScheme(
-                company_id=CompanyID(value=self.vat, schemeID=f'{self.country_code}:VAT'),
-            )
+            if is_peppol_mode():
+                # PEPPOL/CEN UBL-CR-652: No schemeID on PartyTaxScheme/CompanyID
+                return PartyTaxScheme(
+                    company_id=CompanyID(value=self.vat),
+                )
+            else:
+                # Standard mode: Include schemeID
+                from ..identifiers import get_schemes_for_country
+
+                vat_schemes = [
+                    s
+                    for s in get_schemes_for_country(self.country_code)
+                    if s.identifier_type == 'vat' and s.state == 'active'
+                ]
+
+                if vat_schemes:
+                    return PartyTaxScheme(
+                        company_id=CompanyID(value=self.vat, schemeID=vat_schemes[0].iso6523),
+                    )
+
         return None
 
     @property
@@ -1081,12 +1235,14 @@ class Party(CacMixin, BaseElement):
         """
         Legal entity information.
 
+        PEPPOL BIS 3.0 (BR-CL-11) requires numeric ISO 6523 ICD code for schemeID.
+
         Returns:
             PartyLegalEntity with registration name and optional company ID
         """
         company_id = None
         if self.registration and self.country_code:
-            # Use first registration scheme for company_id
+            # Use first registration scheme for company_id (ISO 6523 numeric code)
             from ..identifiers import get_schemes_for_country
 
             reg_schemes = [
@@ -1095,7 +1251,7 @@ class Party(CacMixin, BaseElement):
                 if s.identifier_type == 'registration' and s.state == 'active'
             ]
             if reg_schemes:
-                company_id = CompanyID(value=self.registration, schemeID=reg_schemes[0].scheme_id)
+                company_id = CompanyID(value=self.registration, schemeID=reg_schemes[0].iso6523)
 
         return PartyLegalEntity(registration_name=self.name, company_id=company_id)
 
