@@ -15,6 +15,58 @@ from ..exceptions import ValidationError
 from .common import BaseElement, CbcMixin, ValueStrMixin, WithAsMixin
 
 
+def get_max_decimal_places(*values) -> int:
+    """
+    Get the maximum decimal places from a set of Decimal values.
+
+    Ignores non-Decimal values.
+    Returns 0 if no Decimal values found.
+
+    Args:
+        *values: Variable number of values (may include Decimal, int, float, etc.)
+
+    Returns:
+        Maximum decimal places among Decimal values
+    """
+    max_places = 0
+    for value in values:
+        if isinstance(value, Decimal):
+            # Get the exponent (negative for decimal places)
+            # e.g., Decimal('100.50') has exponent -2 (2 decimal places)
+            exponent = value.as_tuple().exponent
+            if exponent < 0:
+                max_places = max(max_places, abs(exponent))
+    return max_places
+
+
+def quantize_to_max_precision(result: Decimal, *source_values, cap: int | None = 2) -> Decimal:
+    """
+    Quantize a Decimal result to the maximum precision of source values.
+
+    Args:
+        result: The Decimal result of a calculation
+        *source_values: The source Decimal values used in the calculation
+        cap: Maximum decimal places allowed (default: 2 for UBL/PEPPOL compliance)
+             Set to None for unlimited precision
+
+    Returns:
+        Quantized Decimal with precision matching the most precise source value,
+        capped at the specified maximum
+    """
+    max_places = get_max_decimal_places(*source_values)
+
+    # Apply cap if specified
+    if cap is not None:
+        max_places = min(cap, max_places)
+    elif max_places == 0:
+        # No decimal places found and no cap specified, return as-is
+        return result
+
+    # Create quantization template (e.g., '0.01' for 2 places, '1' for 0 places)
+    quantizer = Decimal(10) ** -max_places
+    return result.quantize(quantizer)
+
+
 @dataclass
 class Amount(CbcMixin, WithAsMixin, BaseElement):
     """
@@ -24,6 +76,8 @@ class Amount(CbcMixin, WithAsMixin, BaseElement):
     dataclass level (due to inheritance constraints), it should be treated
     as immutable in practice.
 
+    Automatically preserves decimal precision from the input value.
+
     Attributes:
         value: The numeric amount (must be >= 0)
         currencyID: ISO 4217 currency code (default: EUR)
@@ -33,8 +87,14 @@ class Amount(CbcMixin, WithAsMixin, BaseElement):
     value: Decimal
     currencyID: str = field(default=DEFAULT_CURRENCY_CODE, kw_only=True)
 
-    # Note: Amounts CAN be negative in UBL (credit notes, returns, adjustments)
-    # No additional validation needed beyond type casting from parent mixins
+    def __post_init__(self) -> None:
+        """Ensure value is quantized to preserve its decimal precision (capped at 2 decimals for UBL/PEPPOL)."""
+        # First: trigger type casting through mixin chain
+        self._super_post_init(super())
+
+        # Then: auto-quantize to preserve precision (with 2-decimal cap)
+        if isinstance(self.value, Decimal):
+            self.value = quantize_to_max_precision(self.value, self.value, cap=2)
 
 
 @dataclass
@@ -101,6 +161,8 @@ class BaseIdentifier(CbcMixin, BaseElement, ABC):
     schemeName: str | None = field(default=None, kw_only=True)
     schemeAgencyID: str | None = field(default=None, kw_only=True)
 
+    lowercase_value = False
+
     def __post_init__(self) -> None:
         """
         Process identifier based on scheme type using method dispatch.
@@ -179,8 +241,32 @@ class BaseIdentifier(CbcMixin, BaseElement, ABC):
         pass  # Accept as-is
 
     def _handle_financial_id(self) -> None:
-        """Handle financial IDs (IBAN, BIC) - no validation per user requirement."""
-        pass  # Accept as-is
+        """
+        Handle financial IDs (IBAN, BIC).
+
+        PEPPOL BIS 3.0 format (per base-example.xml):
+        - No schemeID attribute
+        - Value prefixed with "IBAN" or "BIC"
+        - No spaces in value
+
+        Examples:
+            Standard: <cbc:ID schemeID="IBAN">BE20 1030 8550 4356</cbc:ID>
+            PEPPOL:   <cbc:ID>IBANBE20103085504356</cbc:ID>
+        """
+        from ..context import is_peppol_mode
+
+        if is_peppol_mode() and self.schemeID in ('IBAN', 'BIC'):
+            # Strip spaces from value
+            cleaned_value = self.value.replace(' ', '')
+
+            # Prefix with scheme type if not already prefixed
+            if not cleaned_value.startswith(self.schemeID):
+                self.value = f'{self.schemeID}{cleaned_value}'
+            else:
+                self.value = cleaned_value
+
+            # Remove schemeID attribute (PEPPOL requirement)
+            self.schemeID = None
 
     def _handle_peppol_id(self) -> None:
         """
@@ -213,7 +299,7 @@ class BaseIdentifier(CbcMixin, BaseElement, ABC):
                 return
 
         # Step 2: Lowercase if ISO6523 code
-        if self.schemeID.isdigit():
+        if self.schemeID.isdigit() and self.lowercase_value:
             self.value = self.value.lower()
 
         # Step 3: Auto-populate schemeName from scheme.name if not already set
@@ -335,6 +421,8 @@ class EndpointID(BaseIdentifier):
         schemeName: Optional scheme name
     """
 
+    lowercase_value = True
+
     def deserialize(self) -> dict:
         """
         Deserialize endpoint ID to Party attributes.
@@ -637,9 +725,6 @@ class Date(CbcMixin, WithAsMixin, BaseElement):
         else:
             raise TypeError(f'Date value must be date, datetime, or ISO string, got {type(self.value)}')
 
-        # Finally: trigger type casting through mixin chain
-        self._super_post_init(super())
-
 
 @dataclass
 class IssueDate(Date):
