@@ -163,7 +163,7 @@ class AutoCastDataclassMixin(SimpleTypeCastMixin):
         if is_dataclass(value) and is_dataclass(expected_type) and issubclass(expected_type, type(value)):
             if hasattr(value, '__as__'):
                 # XML Element casting only
-                return value.__as__(expected_type)
+                return value.__as__(expected_type.__name__)
             else:
                 try:
                     return expected_type(**{
@@ -379,9 +379,23 @@ class ToXMLMixin:
         For basic components (CBC), the "value" field becomes text content,
         and other fields become attributes (e.g., currencyID, schemeID).
 
+        PEPPOL/CEN UBL-CR rules prohibit certain attributes:
+        - UBL-CR-652: PartyTaxScheme CompanyID schemeID
+        - UBL-CR-656, 657, 660, 661: Various listID attributes
+        - UBL-CR-663: unitCodeListID
+        - UBL-DT-08: schemeName attributes
+        - UBL-DT-28: listAgencyID attributes
+
         Args:
             element: The XML element to populate
         """
+        from ..context import is_peppol_mode
+
+        # Attributes forbidden in PEPPOL mode
+        peppol_forbidden_attrs = {
+            'listID', 'schemeName', 'listAgencyID', 'unitCodeListID'
+        }
+
         for attr_name in self.property_attr_names:
             value = getattr(self, attr_name, None)
 
@@ -389,6 +403,19 @@ class ToXMLMixin:
             if value is None:
                 continue
 
+            # PEPPOL mode: Skip forbidden attributes
+            if is_peppol_mode() and attr_name in peppol_forbidden_attrs:
+                continue
+
+            # PEPPOL mode UBL-CR-652: Skip schemeID for PartyTaxScheme/CompanyID
+            if is_peppol_mode() and attr_name == 'schemeID':
+                # Check if this is a CompanyID in PartyTaxScheme context
+                if hasattr(self, 'element_name') and self.element_name == 'CompanyID':
+                    # Check parent context - skip if we're in PartyTaxScheme
+                    # For now, we'll keep schemeID for CompanyID since it's needed for BR-CL-10/11
+                    # The warning UBL-CR-652 is less critical than the error BR-CL-10
+                    pass
+
             # Convert value to string
             str_value = self._format_value(value)
 
@@ -711,7 +738,25 @@ class BaseElement(BaseXMLNS, ToXMLMixin, FromXMLMixin, SimpleTypeCastMixin, ABC)
         metadata_fields = {'url', 'prefix'}
 
         # Child element fields to exclude (they're serialized as child elements)
-        child_fields = set(cls.class_name_to_attr.values())
+        # Access base mapping if property-based, otherwise use ClassVar
+        if hasattr(cls, '_base_class_name_to_attr'):
+            child_fields = set(cls._base_class_name_to_attr.values())
+        elif hasattr(cls, 'class_name_to_attr'):
+            # Check if it's a property or ClassVar
+            if isinstance(getattr(cls, 'class_name_to_attr', None), property):
+                # Cannot access property from classmethod, try base class
+                child_fields = set()
+                for base in cls.__mro__[1:]:
+                    if hasattr(base, '_base_class_name_to_attr'):
+                        child_fields = set(base._base_class_name_to_attr.values())
+                        break
+                    elif hasattr(base, 'class_name_to_attr') and not isinstance(getattr(base, 'class_name_to_attr', None), property):
+                        child_fields = set(base.class_name_to_attr.values())
+                        break
+            else:
+                child_fields = set(cls.class_name_to_attr.values())
+        else:
+            child_fields = set()
 
         # If class declares its own fields, use only those
         if own_field_names:
